AstToStr

Derive Macro AstToStr 

#[derive(AstToStr)]
{
    // Attributes available to this derive:
    #[skip]
    #[skip_if]
    #[forward]
    #[debug]
    #[display]
    #[quoted]
    #[callback]
    #[default]
    #[list]
    #[rename]
    #[delegate]
}
Automatically implements the AstToStr trait for the given struct or enum. Every field of the given item must implement AstToStr or be annotated with one of the the attributes.